==> Perinci-Examples-Bin-Any-0.02.tar.gz: Perinci-Examples-Bin-Any-0.02/lib/Perinci/Examples/Bin/Any.pm <==
package Perinci::Examples::Bin::Any;

our $DATE = '2014-07-18'; # DATE
our $VERSION = '0.02'; # VERSION

use 5.010001;

1;
# ABSTRACT: Perinci example scripts (using Perinci::CmdLine::Any)

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Any - Perinci example scripts (using Perinci::CmdLine::Any)

=head1 VERSION

This document describes version 0.02 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2014-07-18.

=head1 DESCRIPTION

This distribution contains example scripts in C<bin/> which use
L<Perinci::CmdLine::Any>.

=head1 FAQ

=head2 Where are examples using Perinci::CmdLine::Lite?

You can use the scripts in this distribution, and run them with:

 % PERINCI_CMDLINE_ANY=Perinci::CmdLine::Lite script ...

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Any>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples-Bin-Any>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Any>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Perinci-Examples-Bin-Any-0.04.tar.gz: Perinci-Examples-Bin-Any-0.04/lib/Perinci/Examples/Bin/Any.pm <==
package Perinci::Examples::Bin::Any;

our $DATE = '2014-11-20'; # DATE
our $VERSION = '0.04'; # VERSION

use 5.010001;

1;
# ABSTRACT: Perinci example scripts (using Perinci::CmdLine::Any)

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Any - Perinci example scripts (using Perinci::CmdLine::Any)

=head1 VERSION

This document describes version 0.04 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2014-11-20.

=head1 DESCRIPTION

This distribution contains example scripts in C<bin/> which use
L<Perinci::CmdLine::Any>.

=head1 FAQ

=head2 Where are examples using Perinci::CmdLine::Lite?

You can use the scripts in this distribution, and run them with:

 % PERINCI_CMDLINE_ANY=Perinci::CmdLine::Lite script ...

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Any>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin-Any>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Any>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
